import argparse
import pathlib
import random
import json
import webbrowser

def recommend_album():
    with open(str(pathlib.Path(__file__).parent.absolute()) + "/albums.json") as f:
        albums = json.load(f)

    random_album = albums[random.randrange(0, len(albums) - 1)]

    parser = argparse.ArgumentParser(description='CLI tool recommending you an album from the RYM Charts. 365 should be enough, eh?')
    parser.add_argument(
        "-y",
        "--youtube",
        help="Opens up YouTube and searches for the album",
        action="store_true"
    )

    args = parser.parse_args()

    print(
        f"The album of the day is {random_album['album']} from {random_album['artist']}. The album has a rating of {random_album['rating']} and was released {random_album['release_date']}")

    if args.youtube:
        webbrowser.open(
            f'https://www.youtube.com/results?search_query={random_album["album"].replace(" ", "+")}+{random_album["artist"].replace(" ", "+")}')



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['src']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['discover-daily = src.main:recommend_album']}

setup_kwargs = {
    'name': 'discover-daily',
    'version': '0.1.0',
    'description': 'discover-daily is a CLI tool for all the music nerds out there.',
    'long_description': 'None',
    'author': 'Robert Kossendey',
    'author_email': 'robert.kossendey@protonmail.ch',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)
